@@ -1,36 +1,38 @@
+import json
 import pytest
-import requests_mock
 from decimal import Decimal
+
+from responses import RequestsMock
+import responses
 from santander_sdk.api_client.client import SantanderApiClient
-from santander_sdk.pix import (
-    MAX_UPDATE_STATUS_ATTEMPTS,
-    MAX_UPDATE_STATUS_ATTEMPTS_TO_CONFIRM,
-    transfer_pix,
+from santander_sdk.transfer_flow import (
+    MAX_UPDATE_STATUS_AFTER_CONFIRM,
+    MAX_UPDATE_STATUS_BEFORE_CONFIRM,
 )
+from santander_sdk.pix import transfer_pix
 from mock.santander_mocker import (
     PIX_ENDPOINT_WITH_WORKSPACE,
+    mock_auth_endpoint,
+    mock_workspaces_endpoint,
     santander_beneciary_john,
     beneciary_john_dict_json,
     get_dict_payment_pix_response,
     mock_confirm_pix_endpoint,
     mock_create_pix_endpoint,
-    mock_get_workspaces_endpoint,
     mock_pix_status_endpoint,
-    mock_token_endpoint,
 )
 from santander_sdk.types import OrderStatus
 
 
 @pytest.fixture
-def mock_api(mocker):
-    mocker.patch("santander_sdk.pix.sleep", return_value=None)
-    with requests_mock.Mocker() as m:
-        mock_get_workspaces_endpoint(m)
-        mock_token_endpoint(m)
-        yield m
+def mock_api(mocker, responses: RequestsMock):
+    mocker.patch("santander_sdk.transfer_flow.sleep", return_value=None)
+    mock_workspaces_endpoint()
+    mock_auth_endpoint(responses)
+    return responses
 
 
-def test_transfer_pix_payment_success(mock_api, api_client):
+def test_transfer_pix_payment_success(mock_api, client_instance):
     pix_id = "12345"
     value = Decimal("100.00")
     description = "Pagamento Teste"
@@ -45,7 +47,7 @@ def test_transfer_pix_payment_success(mock_api, api_client):
         mock_api, pix_id, value, OrderStatus.PAYED, pix_key, "CPF"
     )
     transfer_result = transfer_pix(
-        api_client, pix_key, value, description, tags=["teste"]
+        client_instance, pix_key, value, description, tags=["teste"]
     )
     assert transfer_result == {
         "data": {
@@ -85,7 +87,9 @@ def test_transfer_pix_payment_success(mock_api, api_client):
     assert mock_create.call_count == 1
     assert mock_confirm.call_count == 1
     assert mock_status.call_count == 1
-    assert mock_create.request_history[0].json() == {
+    request_body = mock_create.calls[0].request.body
+    assert request_body is not None
+    assert json.loads(request_body) == {
         "tags": ["teste"],
         "paymentValue": "100.00",
         "remittanceInformation": description,
@@ -94,7 +98,9 @@ def test_transfer_pix_payment_success(mock_api, api_client):
     }
 
 
-def test_transfer_pix_payment_timeout_create(api_client: SantanderApiClient, mock_api):
+def test_transfer_pix_payment_timeout_create(
+    client_instance: SantanderApiClient, mock_api
+):
     pix_id = "12345"
     value = Decimal("100.00")
     description = "Pagamento Teste"
@@ -106,19 +112,19 @@ def test_transfer_pix_payment_timeout_create(api_client: SantanderApiClient, moc
     mock_status = mock_pix_status_endpoint(
         mock_api, pix_id, value, OrderStatus.PENDING_VALIDATION, pix_key, "CPF"
     )
-    transfer_result = transfer_pix(api_client, pix_key, value, description)
+    transfer_result = transfer_pix(client_instance, pix_key, value, description)
 
     assert transfer_result == {
         "success": False,
-        "error": "Timeout na atualização do status após várias tentativas: Santander - Limite de tentativas de atualização do status do pagamento PIX atingido",
+        "error": "Status update timeout after several attempts: Santander - Status update attempt limit reached",
         "data": None,
     }
     assert mock_create.call_count == 1
-    assert mock_status.call_count == MAX_UPDATE_STATUS_ATTEMPTS
+    assert mock_status.call_count == MAX_UPDATE_STATUS_BEFORE_CONFIRM
 
 
 def test_transfer_pix_payment_timeout_before_authorize(
-    api_client: SantanderApiClient, mock_api
+    client_instance: SantanderApiClient, mock_api
 ):
     pix_id = "QAS47FASF5646"
     value = Decimal("123.44")
@@ -135,7 +141,7 @@ def test_transfer_pix_payment_timeout_before_authorize(
         mock_api, pix_id, value, OrderStatus.PENDING_CONFIRMATION, pix_key, "CPF"
     )
 
-    transfer_result = transfer_pix(api_client, pix_key, value, description)
+    transfer_result = transfer_pix(client_instance, pix_key, value, description)
     assert transfer_result == {
         "success": True,
         "data": {
@@ -172,11 +178,11 @@ def test_transfer_pix_payment_timeout_before_authorize(
     }
     assert mock_create.call_count == 1
     assert mock_confirm.call_count == 1
-    assert mock_status.call_count == MAX_UPDATE_STATUS_ATTEMPTS_TO_CONFIRM
+    assert mock_status.call_count == MAX_UPDATE_STATUS_AFTER_CONFIRM
 
 
 def test_transfer_pix_payment_rejected_on_create(
-    api_client: SantanderApiClient, mock_api
+    client_instance: SantanderApiClient, mock_api
 ):
     pix_id = "QASF4568E48Q"
     value = Decimal("100.00")
@@ -187,17 +193,17 @@ def test_transfer_pix_payment_rejected_on_create(
         mock_api, pix_id, value, OrderStatus.REJECTED, pix_key, "CPF"
     )
 
-    transfer_result = transfer_pix(api_client, pix_key, value, description)
+    transfer_result = transfer_pix(client_instance, pix_key, value, description)
     assert transfer_result == {
         "success": False,
-        "error": "Rejeição de pagamento: Santander - Pagamento rejeitado pelo banco na etapa Criação do pagamento PIX - Motivo não retornado pelo Santander",
+        "error": "Payment rejection: Santander - Payment rejected by the bank at step CREATE - Reason not returned by Santander",
         "data": None,
     }
     assert mock_create.call_count == 1
 
 
 def test_transfer_pix_payment_rejected_on_confirm(
-    api_client: SantanderApiClient, mock_api
+    client_instance: SantanderApiClient, mock_api
 ):
     pix_id = "5A4SD6Q5W6Q68A"
     value = Decimal("157.00")
@@ -210,23 +216,19 @@ def test_transfer_pix_payment_rejected_on_confirm(
     mock_confirm = mock_confirm_pix_endpoint(
         mock_api, pix_id, value, OrderStatus.REJECTED, pix_key, "CPF"
     )
-    mock_status = mock_pix_status_endpoint(
-        mock_api, pix_id, value, OrderStatus.REJECTED, pix_key, "CPF"
-    )
 
-    transfer_result = transfer_pix(api_client, pix_key, value, description)
+    transfer_result = transfer_pix(client_instance, pix_key, value, description)
     assert transfer_result == {
         "success": False,
-        "error": "Rejeição de pagamento: Santander - Pagamento rejeitado pelo banco na etapa Confirmação do pagamento PIX - Motivo não retornado pelo Santander",
+        "error": "Payment rejection: Santander - Payment rejected by the bank at step CONFIRM - Reason not returned by Santander",
         "data": None,
     }
     assert mock_create.call_count == 1
     assert mock_confirm.call_count == 1
-    assert mock_status.call_count == 0
 
 
 def test_transfer_pix_payment_with_beneficiary(
-    api_client: SantanderApiClient, mock_api
+    client_instance: SantanderApiClient, mock_api
 ):
     pix_id = "ASF5Q7Q879WQ"
     value = Decimal("59.99")
@@ -247,7 +249,7 @@ def test_transfer_pix_payment_with_beneficiary(
     )
 
     transfer_result = transfer_pix(
-        api_client, santander_beneciary_john, value, description
+        client_instance, santander_beneciary_john, value, description
     )
     assert transfer_result == {
         "success": True,
@@ -288,7 +290,7 @@ def test_transfer_pix_payment_with_beneficiary(
 
 
 def test_transfer_pix_payment_lazy_status_update(
-    api_client: SantanderApiClient, mock_api
+    client_instance: SantanderApiClient, mock_api
 ):
     pix_id = "12345"
     value = Decimal("130000.00")
@@ -301,33 +303,22 @@ def test_transfer_pix_payment_lazy_status_update(
     mock_confirm = mock_confirm_pix_endpoint(
         mock_api, pix_id, value, OrderStatus.PAYED, pix_key, "CPF"
     )
-    mock_status = mock_api.get(
-        f"{PIX_ENDPOINT_WITH_WORKSPACE}/{pix_id}",
-        [
-            {
-                "json": get_dict_payment_pix_response(
-                    pix_id, value, OrderStatus.PENDING_VALIDATION, pix_key, "CPF"
-                )
-            },
-            {
-                "json": get_dict_payment_pix_response(
-                    pix_id, value, OrderStatus.PENDING_VALIDATION, pix_key, "CPF"
-                )
-            },
-            {
-                "json": get_dict_payment_pix_response(
-                    pix_id, value, OrderStatus.READY_TO_PAY, pix_key, "CPF"
-                )
-            },
-            {
-                "json": get_dict_payment_pix_response(
-                    pix_id, value, OrderStatus.READY_TO_PAY, pix_key, "CPF"
-                )
-            },
-        ],
-    )
 
-    transfer_result = transfer_pix(api_client, pix_key, value, description)
+    mock_status_pending = mock_api.add(
+        responses.GET,
+        f"{PIX_ENDPOINT_WITH_WORKSPACE}/{pix_id}",
+        json=get_dict_payment_pix_response(
+            pix_id, value, OrderStatus.PENDING_VALIDATION, pix_key, "CPF"
+        ),
+    )
+    mock_status_ready = mock_api.add(
+        responses.GET,
+        f"{PIX_ENDPOINT_WITH_WORKSPACE}/{pix_id}",
+        json=get_dict_payment_pix_response(
+            pix_id, value, OrderStatus.READY_TO_PAY, pix_key, "CPF"
+        ),
+    )
+    transfer_result = transfer_pix(client_instance, pix_key, value, description)
     assert transfer_result == {
         "success": True,
         "data": {
@@ -362,8 +353,7 @@ def test_transfer_pix_payment_lazy_status_update(
         },
         "error": "",
     }
-    assert mock_create.call_count == 1, "Deveria ter chamado a criação do PIX uma vez"
-    assert mock_confirm.call_count == 1, (
-        "Deveria ter chamado a confirmação do PIX uma vez"
-    )
-    assert mock_status.call_count == 3, "Deveria ter chamado o status do PIX três vezes"
+    assert mock_create.call_count == 1
+    assert mock_confirm.call_count == 1
+    assert mock_status_pending.call_count == 1
+    assert mock_status_ready.call_count == 1
